
Fendt926 = {};

function Fendt926.prerequisitesPresent(specializations)
    return SpecializationUtil.hasSpecialization(Motorized, specializations);
end;

function Fendt926:load(xmlFile)

	self.exhaustFlap = Utils.indexToObject(self.components, getXMLString(xmlFile, "vehicle.exhaustFlap#index"));
	
	self.frontholder = {};
	self.frontholder.object = Utils.indexToObject(self.components, getXMLString(xmlFile, "vehicle.frontholder#index"));
	self.frontholder.refPoint = Utils.indexToObject(self.components, getXMLString(xmlFile, "vehicle.frontholder#referencePoint"));
	self.frontholder.refRotX = Utils.getNoNil(getXMLFloat(xmlFile, "vehicle.frontholder#referenceRotX"), -1.04); 
	
	self.backholder = {};
	self.backholder.object = Utils.indexToObject(self.components, getXMLString(xmlFile, "vehicle.backholder#index"));
	self.backholder.refPoint = Utils.indexToObject(self.components, getXMLString(xmlFile, "vehicle.backholder#referencePoint"));
	self.backholder.refRotX = Utils.getNoNil(getXMLFloat(xmlFile, "vehicle.backholder#referenceRotX"), 1.30); 
	
	local numWorkLights = Utils.getNoNil(getXMLInt(xmlFile, "vehicle.worklights#count"), 0);
    self.worklights = {};
    for i=1, numWorkLights do
        local worklightnamei = string.format("vehicle.worklights.worklight%d", i);
        self.worklights[i] = Utils.indexToObject(self.components, getXMLString(xmlFile, worklightnamei .. "#index"));
        setVisibility(self.worklights[i], false);
    end;
	self.worklightsActive = false;
	
	self.helpPanelPath = Utils.getFilename("Fendt926HUD.png", self.baseDirectory);
	self.HudWidth = 0.386;
	self.HudHeight = 0.252; --old 0.256;
	self.HudPosX = 0.001;
	self.HudPosY = 0.001;
	self.helpPanelTextPosX = 0.002;
	self.helpPanelTextPosY = 0.356;
	self.helpPanelOverlay = Overlay:new("Helppanel", self.helpPanelPath, self.HudPosX, self.HudPoxY, self.HudWidth, self.HudHeight);
	self.helpPanelActive = false;

end;

function Fendt926:delete()
end;

function Fendt926:mouseEvent(posX, posY, isDown, isUp, button)
end;

function Fendt926:keyEvent(unicode, sym, modifier, isDown)

end;

function Fendt926:stopMotor()
    self.motor.minRpm = self.backupMinRpm;
end;

function Fendt926:update(dt)

	if self.isMotorStarted then
		local rotX, rotY, rotZ = getRotation(self.exhaustFlap);
		local rotX = Utils.degToRad((self.motor.nonClampedMotorRpm+200)/28);
		if self.motor.minRpm < 0 then
			rotX = rotX-Utils.degToRad(self.motor.minRpm/28);
		else
			rotX = rotX
		end;
		if rotX < Utils.degToRad(0) then
			rotX = Utils.degToRad(0);
		end;
		if rotX > Utils.degToRad(70) then
			rotX = Utils.degToRad(70);
		end;
		setRotation(self.exhaustFlap, rotX*-1, rotY, rotZ);
	else
		setRotation(self.exhaustFlap, 0, rotY, rotZ);
	end;
	
	if self.isEntered then
		if InputBinding.hasEvent(InputBinding.WORKLIGHTS) then
			self.worklightsActive = not self.worklightsActive;
		end;
		
		if InputBinding.hasEvent(InputBinding.HELPPANELFENDT926) then
			self.helpPanelActive = not self.helpPanelActive;
		end;
	end;
	
	for k, worklight in pairs(self.worklights) do
		setVisibility(worklight, self.worklightsActive);
	end;
		
	if self.frontholder.refPoint ~= nil and self.frontholder.refRotX ~= nil then
		local xRefPointFront, yRefPointFront, zRefPointFront = getRotation(self.frontholder.refPoint);
		local xRefPointBack, yRefPointBack, zRefPointBack = getRotation(self.backholder.refPoint);
		if math.floor(xRefPointFront*100)/100 ~= self.frontholder.refRotX then
			setRotation(self.frontholder.object, Utils.degToRad(69.21102), 0, 0);
		else
			setRotation(self.frontholder.object, Utils.degToRad(-1.34007), 0, 0);
		end;
		if math.floor(xRefPointBack*100)/100 ~= self.backholder.refRotX then
			setRotation(self.backholder.object, Utils.degToRad(-67.97647), 0, 0);
		else
			setRotation(self.backholder.object, Utils.degToRad(-0.30185), 0, 0);
		end;
	end;		
end;

function Fendt926:onLeave()
	for k, worklight in pairs(self.worklights) do
		setVisibility(worklight, false);
	end;
	self.worklightsActive = false;
end;

function Fendt926:draw()

	if self.helpPanelActive then
		self.helpPanelOverlay:render();
		renderText(self.helpPanelTextPosX, self.helpPanelTextPosY-0.135, 0.025, string.format("Taste %s: %s", InputBinding.getButtonKeyName(InputBinding.HELPPANELFENDT926), g_i18n:getText("fendt926HelpPanelOn")));
		if self.moveableAttacher ~= nil then
			renderText(self.helpPanelTextPosX, self.helpPanelTextPosY-0.159, 0.024, string.format("Taste %s/%s: %s/%s", InputBinding.getButtonKeyName(InputBinding.ATTACHER_UP), InputBinding.getButtonKeyName(InputBinding.ATTACHER_DOWN), g_i18n:getText("attacherUp"), g_i18n:getText("attacherDown")));
		end;
		if not self.isMotorStarted and not self.automaticStart then	
			renderText(self.helpPanelTextPosX, self.helpPanelTextPosY-0.207, 0.024, string.format("Taste %s: %s", InputBinding.getButtonKeyName(InputBinding.IGNITION), g_i18n:getText("FendtStart")));
		end;
		if self.worklightsActive then
			renderText(self.helpPanelTextPosX, self.helpPanelTextPosY-0.183, 0.024, string.format("Taste %s: %s", InputBinding.getButtonKeyName(InputBinding.WORKLIGHTS), g_i18n:getText("worklightOff")));
		else
			renderText(self.helpPanelTextPosX, self.helpPanelTextPosY-0.183, 0.024, string.format("Taste %s: %s", InputBinding.getButtonKeyName(InputBinding.WORKLIGHTS), g_i18n:getText("worklightOn")));
		end;
		if self.isMotorStarted then	
			if self.motor.speedLevel ~= 0 then
				renderText(self.helpPanelTextPosX, self.helpPanelTextPosY-0.207, 0.024, string.format("Taste %s/%s: %d RPM", InputBinding.getButtonKeyName(InputBinding.ACCELERATE), InputBinding.getButtonKeyName(InputBinding.DECELERATE), self.motor.maxRpm[self.motor.speedLevel]));
			else
				renderText(self.helpPanelTextPosX, self.helpPanelTextPosY-0.207, 0.024, string.format("Taste %s/%s: %d RPM", InputBinding.getButtonKeyName(InputBinding.ACCELERATE), InputBinding.getButtonKeyName(InputBinding.DECELERATE), self.motor.maxRpm[3]));
			end;
			if self.reverse then
				renderText(self.helpPanelTextPosX, self.helpPanelTextPosY-0.231, 0.024, string.format("Taste %s: %s", InputBinding.getButtonKeyName(InputBinding.REVERSE), g_i18n:getText("FendtshuttleReverser1")));
			else
				renderText(self.helpPanelTextPosX, self.helpPanelTextPosY-0.231, 0.024, string.format("Taste %s: %s", InputBinding.getButtonKeyName(InputBinding.REVERSE), g_i18n:getText("FendtshuttleReverser2")));
			end;
			if self.handThrottleEnabled then
				renderText(self.helpPanelTextPosX, self.helpPanelTextPosY-0.255, 0.024, string.format("Taste %s: Standgas Regelung EIN", InputBinding.getButtonKeyName(InputBinding.RESETRPM)));
			else
				renderText(self.helpPanelTextPosX, self.helpPanelTextPosY-0.255, 0.024, string.format("Taste %s: Standgas Regelung AUS", InputBinding.getButtonKeyName(InputBinding.RESETRPM)));
			end;
				renderText(self.helpPanelTextPosX, self.helpPanelTextPosY-0.279, 0.024, string.format("Taste %s/%s: %s", InputBinding.getButtonKeyName(InputBinding.LESSRPM), InputBinding.getButtonKeyName(InputBinding.MORERPM), g_i18n:getText("Gas")));
		end;
		if self.rundumleuchtenAnz > 0 and self:getIsActive() then
			renderText(self.helpPanelTextPosX, self.helpPanelTextPosY-0.303, 0.024, string.format("Taste %s: %s", InputBinding.getButtonKeyName(InputBinding.RUNDUMLEUCHTE), g_i18n:getText("rundumleuchte")));
		end;
		if self.fieldMode then
			renderText(self.helpPanelTextPosX, self.helpPanelTextPosY-0.327, 0.024, string.format("Taste %s: %s", InputBinding.getButtonKeyName(InputBinding.MODE), g_i18n:getText("fieldMode")));
		else
			renderText(self.helpPanelTextPosX, self.helpPanelTextPosY-0.327, 0.024, string.format("Taste %s: %s", InputBinding.getButtonKeyName(InputBinding.MODE), g_i18n:getText("transportMode")));
		end;
		if self.tempOnBord then
			local red = 0.0;
			local green = 0.0;
			local blue = 0.0;
			if self.temp < 70 then
				red = 0.0;
				green = 0.0;
				blue = 1.0;
			elseif self.temp >= 70 and self.temp <= 95 then
				blue = 0.0;
				red = 0.0;
				green = 1.0;
			elseif self.temp > 95 then
				red = 1.0;
				green = 0.0;
				blue = 0.0;
			end;
			setTextColor(red, green, blue, 1.0);
			renderText(self.helpPanelTextPosX, self.helpPanelTextPosY-0.351, 0.024, string.format("                          %d 'C", self.temp));
			setTextColor(1.0, 1.0, 1.0, 1.0);
			renderText(self.helpPanelTextPosX, self.helpPanelTextPosY-0.351, 0.024, string.format("Khlmitteltemperatur:"));
		end;
	else
		if not self.isMotorStarted and not self.automaticStart then	
			g_currentMission:addHelpButtonText(g_i18n:getText("FendtStart"), InputBinding.IGNITION);
		end;
		g_currentMission:addHelpButtonText(g_i18n:getText("fendt926HelpPanelOff"), InputBinding.HELPPANELFENDT926);
	end;
end;

function Fendt926:validateAttacherJoint(implement, jointDesc, dt)
    return true;
end;

