varioSystem = {};

function varioSystem.prerequisitesPresent(specializations)
    return SpecializationUtil.hasSpecialization(Motorized, specializations);
end;

function varioSystem:load(xmlFile)
	self.backupMinRpm = Utils.getNoNil(getXMLFloat(xmlFile, "vehicle.motor#minRpm"), 1000);
	local motorMaxRpmStr = getXMLString(xmlFile, "vehicle.motor#maxRpm");
    local motorMaxRpm1, motorMaxRpm2, motorMaxRpm3 = Utils.getVectorFromString(motorMaxRpmStr);
    motorMaxRpm1 = Utils.getNoNil(motorMaxRpm1, 800);
    motorMaxRpm2 = Utils.getNoNil(motorMaxRpm2, 1000);
    motorMaxRpm3 = Utils.getNoNil(motorMaxRpm3, 1800);
	self.fieldMode = false;
	self.backUpBrakeForce = Utils.getNoNil(getXMLFloat(xmlFile, "vehicle.motor#brakeForce"), 10)*2;
	self.backUpBackwardGearRatio = Utils.getNoNil(getXMLFloat(xmlFile, "vehicle.motor#backwardGearRatio"), 1.5);
	self.backUpMaxRpm = motorMaxRpm3;
	self.temp = 25;
	self.cooling = false;
	self.warmUpTime = 0;
	self.coolingTemp = 0;
	self.seconds = 0;
	self.tempOnBord = true;
	self.tempbackup = 0;
end;

function varioSystem:loadFromAttributesAndNodes(xmlFile, key, resetVehicles)
	local temp = getXMLFloat(xmlFile, key.."#temp");
    if temp ~= nil then
		self.temp = temp;
    end;
    return BaseMission.VEHICLE_LOAD_OK;
end;

function varioSystem:getSaveAttributesAndNodes(nodeIdent)
    local attributes = 'temp="'..self.temp..'"';
    return attributes, nil;
end;

function varioSystem:delete()
end;

function varioSystem:mouseEvent(posX, posY, isDown, isUp, button)
end;

function varioSystem:keyEvent(unicode, sym, modifier, isDown)

end;

function varioSystem:update(dt)

    self.input = InputBinding.getAnalogInputAxis(InputBinding.AXIS_FORWARD);
	if InputBinding.isAxisZero(self.input) then
		self.input = InputBinding.getDigitalInputAxis(InputBinding.AXIS_FORWARD);
	end;
	local maxRpm = self.motor:getMaxRpm();
	local torque = self.motor.torqueCurve:get(self.motor.lastMotorRpm);
	if self.input ~= 0 or self.motor.speedLevel ~= 0 then
		if self.handThrottleOnBoard then
			self.handThrottleEnabled = false;
		end;
		local differenz = maxRpm-self.motor.lastMotorRpm;
		if self.handThrottleEnabled == false then
			if differenz <= 333 then
				self.motor.minRpm = self.motor.minRpm+(differenz/50);
			else
				self.motor.minRpm = self.motor.minRpm-(differenz/25);
			end;
			if self.motor.minRpm <= -550 then
				self.motor.minRpm = -550;
			elseif self.motor.minRpm >= 1200 then
				self.motor.minRpm = 1200;
			end;
			if self.fieldMode then
				self.motor.minRpm = (self.motor.minRpm-180);
			else
				self.motor.minRpm = self.motor.minRpm;
			end;
		else
			self.motor.minRpm = self.backupMinRpm;
		end;
	elseif self.handThrottleEnabled == false then
		self.motor.minRpm = self.backupMinRpm;
	end;
	
	if self.isEntered then
		if InputBinding.hasEvent(InputBinding.MODE) then
			self.fieldMode = not self.fieldMode;
		end;
	end;
	
	if self.tempOnBord then
		local powerDifferenz = 50;
		if self.input ~= 0 or self.motor.speedLevel ~= 0 then
			powerDifferenz = maxRpm-self.motor.lastMotorRpm;
		end;
		if self.isMotorStarted then
			if self.temp < 60 then
				if powerDifferenz >= 90 then
					self.warmUpTime = (0.7/dt)-self.coolingTemp;
				else
					self.warmUpTime = (0.12/dt)-self.coolingTemp;
				end;
			elseif self.temp >= 60 and self.temp < 75 then
				if powerDifferenz >= 120 then
					self.warmUpTime = (0.21/dt)-self.coolingTemp;
				else
					self.warmUpTime = (0.018/dt)-self.coolingTemp;
				end;
			elseif self.temp >= 75 then
				if powerDifferenz >= 150 then
					self.warmUpTime = (0.23/dt)-self.coolingTemp;
				else
					self.warmUpTime = (0.009/dt)-self.coolingTemp;
				end;
			end;
			if self.temp > 99 then
				self.cooling = true;
			elseif self.cooling == true and self.temp <= 83 then
				self.cooling = false;
			end;
			if self.cooling then
				self.coolingTemp = 0.025/(dt/(self.motor.lastMotorRpm/6));
			else
				self.coolingTemp = 0.001/(dt/(self.motor.lastMotorRpm/24));
			end;
		else
			self.coolingTemp = 0.92/(-dt*g_currentMission.environment.timeScale);
			self.warmUpTime = self.coolingTemp;
		end;
		if self.temp < self.tempbackup then
			self.temp = self.tempbackup;
		else
			self.temp = self.temp;
		end;
		self.temp = self.temp+self.warmUpTime;
		if self.temp <= 23 then
			self.temp = 24;
		end;
	end;
	
end;

function varioSystem:stopMotor()
    self.motor.minRpm = self.backupMinRpm;
	self.tempbackup = self.temp;
end;

function varioSystem:onEnter()
	self.temp = self.tempbackup;
end;
	
function varioSystem:onLeave()
    self.motor.minRpm = self.backupMinRpm;
	self.tempbackup = self.temp;
end;

function varioSystem:draw()
        
end;
